@@ -1,12 +1,12 @@
 pub mod epoll;
 pub(super) mod error;
-#[cfg(all(not(feature = "std"), feature = "rustc-dep-of-std"))]
+#[cfg(not(feature = "std"))]
 mod io_slice;
 mod poll_fd;
 mod types;
 
 pub use error::Error;
-#[cfg(all(not(feature = "std"), feature = "rustc-dep-of-std"))]
+#[cfg(not(feature = "std"))]
 pub use io_slice::{IoSlice, IoSliceMut};
 pub use poll_fd::{PollFd, PollFlags};
 pub use types::{
