@@ -2,9 +2,9 @@
 
 use crate::imp;
 
-#[cfg(all(not(feature = "std"), feature = "rustc-dep-of-std"))]
+#[cfg(not(feature = "std"))]
 mod addr;
-#[cfg(all(not(feature = "std"), feature = "rustc-dep-of-std"))]
+#[cfg(not(feature = "std"))]
 mod ip;
 mod send_recv;
 mod socket;
@@ -37,9 +37,9 @@ pub use imp::net::SocketAddrStorage;
 pub use imp::net::SocketAddrUnix;
 
 // Declare the `Ip` and `Socket` address types.
-#[cfg(all(not(feature = "std"), feature = "rustc-dep-of-std"))]
+#[cfg(not(feature = "std"))]
 pub use addr::{SocketAddr, SocketAddrV4, SocketAddrV6};
-#[cfg(all(not(feature = "std"), feature = "rustc-dep-of-std"))]
+#[cfg(not(feature = "std"))]
 pub use ip::{IpAddr, Ipv4Addr, Ipv6Addr, Ipv6MulticastScope};
 #[cfg(feature = "std")]
 pub use std::net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddrV4, SocketAddrV6};
